==> simple_date_repeat_ui-6.x-1.0.tar.gz: simple_date_repeat_ui/js/simple_date_repeat_ui.js <==
Drupal.behaviors.simpleDateRepeatUi = function() {
  Drupal.simpleDateRepeatUi();
}

Drupal.simpleDateRepeatUi = function() {
  var chb = $('.simple-repeat-check');
  var rruleDesc = $('.rrule-desc');
  var form = $('#' + Drupal.settings.simple_date_repeat_ui.form_id);
  var $date = '';
  var date_val = '';
  var $fieldname = Drupal.settings.simple_date_repeat_ui.field;
  
  $dialog = function(args) {
  	$('.repeat-popup').dialog(args);
  }
  init = function() {
  	$dialog({
  	  autoOpen: false,
  	  draggable: false,
  	  modal: true,
  	  resizable: false,
  	  title: Drupal.t('Repeats'),
  	  closeText: '',
  	  buttons: {
  	    'Done': function() {$dialog('close'); saveRepeat();},
  	    'Cancel': function() {$dialog('close'); uncheck();},
  	  },
  	  
    });
    var link = $('<a></a>');
    link.attr('href', '#');
    link.addClass('rrule-edit');
    link.text(Drupal.t('Edit'));
    link.appendTo(chb.parent().parent());
    if(!chb.is(':checked')) {
    	$('.rrule-edit').hide();
    }
    attachEvents();
    $('#repeat-byday, #repeat-bymonth, .repeat-clone').hide();
    $('.rrule-sum').css('display', 'block');
  }
  
  uncheck = function() {
  	chb.attr('checked', false);
  	clearRepeat();
  }
  
  attachEvents = function() {
  	chb.bind('change', function () {
  	  if($(this).is(':checked')) {
  	  	open();
  	  }
  	  else {
  	  	clearRepeat()
  	  }
  	});
  	$('.rrule-edit').live('click', function() {
  	  open();
  	  return false;
  	});
  	$(form).bind('submit', function() { saveRepeat(true); moveForm(); });
  	$('#repeat-freq select').live('change', function() { showExtra($(this)); }).trigger('change');
  	$('.repeat-popup :input').live('change', function() { updateDesc(true); });
  }
  
  open = function() {
    inputname = 'input[name="' + $fieldname +  '[value][date]"]';
    date_val = $(inputname).val();
    if(date_val != '') {
      $date = new Date(date_val);
    }
    $('.repeat-clone').empty().remove();
  	$dialog('open');
  	$('#repeat-freq select').trigger('change');
  }
  
  clearRepeat = function() {
    hideExtra();
  	rruleDesc.hide();
  	$('.rrule-edit').hide();
  }
  
  saveRepeat = function(noAjax) {
  	if (!noAjax){
  	  updateDesc();
  	  rruleDesc.show();
  	}
  	$('.rrule-edit').show();
  }
  
  moveForm = function() {
    $('.repeat-popup :input').each(function() {
      $val = $(this).val();
      $name = $(this).attr('name');
      if ((($(this).attr('type') == 'checkbox' || $(this).attr('type') == 'radio') && $(this).is(':checked')) || $(this).attr('type') != 'checkbox'){
        $('<input type="hidden"></input>').attr({
          'name': $name,
        })
        .val($val)
        .appendTo(form);
      }
    });
  }
  
  updateDesc = function(only) {
  	$url = Drupal.settings.basePath + 'date_repeat_rrule_desc';
  	$data = $('.repeat-popup :input').serialize();
  	$data = $data + '&' + $fieldname + '[value][date]=' + date_val;
  	$.ajax({
      url: $url,
      data: $data,
      dataType: 'json',
      type: 'POST',
      success: function(data) {
        if (only === true) {
         $('.repeat-popup .rrule-desc').text(data.rrule);
         return;
        }
        rruleDesc.text(data.rrule);
      },
  	});
  }
  
  showExtra = function(input) {
    hideExtra(input.val());
    if (input.val() == 'WEEKLY'){
      showByDay();
    }
    if (input.val() == 'MONTHLY'){
      showByMonthDay();
    }
    
  }
  
  hideExtra = function(val) {
    hideByDay(val);
    hideByMonthDay(val);
  }
  
  showByDay = function() {
    if ($date) {
      day = $date.getDay();
      $('#repeat-byday input[type="checkbox"]').eq(day).attr('checked', true);
    }
    $('#repeat-byday').show();
  }
  hideByDay = function(val) {
    $('#repeat-byday').hide();
  }
  
  showByMonthDay = function() {
    $('#repeat-bymonth').show();
  }
  hideByMonthDay = function() {
    $('#repeat-bymonth').hide();
  }
  
  init();
}

==> simple_date_repeat_ui-6.x-1.1.tar.gz: simple_date_repeat_ui/js/simple_date_repeat_ui.js <==
Drupal.behaviors.simpleDateRepeatUi = function() {
  Drupal.simpleDateRepeatUi();
}

Drupal.simpleDateRepeatUi = function() {
  var chb = $('.simple-repeat-check');
  var rruleDesc = $('.rrule-desc');
  var form = $('#' + Drupal.settings.simple_date_repeat_ui.form_id);
  var $date = '';
  var date_val = '';
  var $fieldname = Drupal.settings.simple_date_repeat_ui.field;
  var $interval_text = {
    'DAILY': Drupal.t('days'),
    'WEEKLY': Drupal.t('weeks'),
    'MONTHLY': Drupal.t('months'),
    'YEARLY': Drupal.t('years'),    
  };
  
  $dialog = function(args) {
  	$('.repeat-popup').dialog(args);
  }
  init = function() {
  	$dialog({
  	  autoOpen: false,
  	  draggable: false,
  	  modal: true,
  	  resizable: false,
  	  title: Drupal.t('Repeats'),
  	  closeText: '',
  	  buttons: {
  	    'Done': function() {$dialog('close'); saveRepeat();},
  	    'Cancel': function() {$dialog('close'); uncheck();},
  	  },
  	  
    });
    var link = $('<a></a>');
    link.attr('href', '#');
    link.addClass('rrule-edit');
    link.text(Drupal.t('Edit'));
    link.appendTo(chb.parent().parent());
    if(!chb.is(':checked')) {
    	$('.rrule-edit').hide();
    }
    attachEvents();
    $('#repeat-byday, #repeat-bymonth, .repeat-clone').hide();
    $('.rrule-sum').css('display', 'block');
  }
  
  uncheck = function() {
  	chb.attr('checked', false);
  	clearRepeat();
  }
  
  attachEvents = function() {
  	chb.bind('change', function () {
  	  if($(this).is(':checked')) {
  	  	open();
  	  }
  	  else {
  	  	clearRepeat()
  	  }
  	});
  	$('.rrule-edit').live('click', function() {
  	  open();
  	  return false;
  	});
  	$(form).bind('submit', function() { saveRepeat(true); moveForm(); });
  	$('#repeat-freq select').live('change', function() { showExtra($(this)); changeInterval($(this).val())}).trigger('change');
  	$('.repeat-popup :input').live('change', function() { updateDesc(true); });
  }
  
  open = function() {
    inputname = 'input[name="' + $fieldname +  '[value][date]"]';
    date_val = $(inputname).val();
    if(date_val != '') {
      $date = new Date(date_val);
    }
    $('.repeat-clone').empty().remove();
  	$dialog('open');
  	$('#repeat-freq select').trigger('change');
  }
  
  clearRepeat = function() {
    hideExtra();
  	rruleDesc.hide();
  	$('.rrule-edit').hide();
  }
  
  saveRepeat = function(noAjax) {
  	if (!noAjax){
  	  updateDesc();
  	  rruleDesc.show();
  	}
  	$('.rrule-edit').show();
  }
  
  moveForm = function() {
    $('.repeat-popup :input').each(function() {
      $val = $(this).val();
      $name = $(this).attr('name');
      if ((($(this).attr('type') == 'checkbox' || $(this).attr('type') == 'radio') && $(this).is(':checked')) || $(this).attr('type') != 'checkbox'){
        $('<input type="hidden"></input>').attr({
          'name': $name,
        })
        .val($val)
        .appendTo(form);
      }
    });
  }
  
  updateDesc = function(only) {
  	$url = Drupal.settings.basePath + 'date_repeat_rrule_desc';
  	$data = $('.repeat-popup :input').serialize();
  	$data = $data + '&' + $fieldname + '[value][date]=' + date_val;
  	$.ajax({
      url: $url,
      data: $data,
      dataType: 'json',
      type: 'POST',
      success: function(data) {
        if (only === true) {
         $('.repeat-popup .rrule-desc').text(data.rrule);
         return;
        }
        rruleDesc.text(data.rrule);
      },
  	});
  }
  
  showExtra = function(input) {
    hideExtra(input.val());
    if (input.val() == 'WEEKLY'){
      showByDay();
    }
    if (input.val() == 'MONTHLY'){
      showByMonthDay();
    }
    
  }
  
  hideExtra = function(val) {
    hideByDay(val);
    hideByMonthDay(val);
  }
  
  showByDay = function() {
    if ($date) {
      day = $date.getDay();
      $('#repeat-byday input[type="checkbox"]').eq(day).attr('checked', true);
    }
    $('#repeat-byday').show();
  }
  hideByDay = function(val) {
    $('#repeat-byday').hide();
  }
  
  showByMonthDay = function() {
    $('#repeat-bymonth').show();
  }
  hideByMonthDay = function() {
    $('#repeat-bymonth').hide();
  }
  
  changeInterval = function($val) {
    $('#repeat-int-type').text($interval_text[$val]);  
  }
  
  init();
}
